ahbicht.content\_evaluation package
===================================

Submodules
----------

.. toctree::
   :maxdepth: 4

   ahbicht.content_evaluation.evaluationdatatypes
   ahbicht.content_evaluation.evaluators
   ahbicht.content_evaluation.fc_evaluators
   ahbicht.content_evaluation.rc_evaluators

Module contents
---------------

.. automodule:: ahbicht.content_evaluation
   :members:
   :undoc-members:
   :show-inheritance:
